@@ -2,6 +2,7 @@ package docker
 
 import (
 	"bytes"
+	"flag"
 	"fmt"
 	"io/ioutil"
 	"os"
@@ -25,6 +26,13 @@ import (
 	"golang.org/x/net/context"
 )
 
+func TestMain(m *testing.M) {
+	DockerPrebuiltImagesPaths = []string{"../../out/helper-images/"}
+
+	flag.Parse()
+	os.Exit(m.Run())
+}
+
 // ImagePullOptions contains the RegistryAuth which is inferred from the docker
 // configuration for the user, so just mock it out here.
 func buildImagePullOptions(e executor, configName string) mock.AnythingOfTypeArgument {
@@ -840,15 +848,16 @@ func TestDockerWatchOn_1_12_4(t *testing.T) {
 
 	e.Config = common.RunnerConfig{}
 	e.Config.Docker = &common.DockerConfig{
-		PullPolicy: common.PullPolicyAlways,
+		PullPolicy: common.PullPolicyIfNotPresent,
 	}
 
-	e.Trace = &common.Trace{Writer: os.Stdout}
+	output := bytes.NewBufferString("")
+	e.Trace = &common.Trace{Writer: output}
 
 	err := e.connectDocker()
 	assert.NoError(t, err)
 
-	container, err := e.createContainer("build", common.Image{Name: "alpine"}, []string{"/bin/sh"}, []string{})
+	container, err := e.createContainer("build", common.Image{Name: common.TestAlpineImage}, []string{"/bin/sh"}, []string{})
 	assert.NoError(t, err)
 	assert.NotNil(t, container)
 
@@ -860,13 +869,13 @@ func TestDockerWatchOn_1_12_4(t *testing.T) {
 	go func() {
 		err = e.watchContainer(e.Context, container.ID, input)
 		assert.NoError(t, err)
-		t.Log(err)
 		finished <- true
 		wg.Done()
 	}()
 
 	select {
 	case <-finished:
+		assert.Equal(t, "script\n", output.String())
 	case <-time.After(15 * time.Second):
 		t.Error("Container script not finished")
 	}
