@@ -18,13 +18,10 @@ import (
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
-	"k8s.io/kubernetes/pkg/api"
-	"k8s.io/kubernetes/pkg/api/resource"
-	"k8s.io/kubernetes/pkg/api/testapi"
-	"k8s.io/kubernetes/pkg/api/unversioned"
-	"k8s.io/kubernetes/pkg/client/restclient"
-	client "k8s.io/kubernetes/pkg/client/unversioned"
-	"k8s.io/kubernetes/pkg/client/unversioned/fake"
+	api "k8s.io/api/core/v1"
+	"k8s.io/apimachinery/pkg/api/resource"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/client-go/rest/fake"
 
 	"gitlab.com/gitlab-org/gitlab-runner/common"
 	"gitlab.com/gitlab-org/gitlab-runner/executors"
@@ -275,19 +272,18 @@ func TestVolumes(t *testing.T) {
 }
 
 func fakeKubeDeleteResponse(status int) *http.Response {
-	codec := testapi.Default.Codec()
+	_, codec := testVersionAndCodec()
 
-	body := objBody(codec, &unversioned.Status{Code: int32(status)})
+	body := objBody(codec, &metav1.Status{Code: int32(status)})
 	return &http.Response{StatusCode: status, Body: body, Header: map[string][]string{
 		"Content-Type": []string{"application/json"},
 	}}
 }
 
 func TestCleanup(t *testing.T) {
-	version := testapi.Default.GroupVersion().Version
-	codec := testapi.Default.Codec()
+	version, _ := testVersionAndCodec()
 
-	objectMeta := api.ObjectMeta{Name: "test-resource", Namespace: "test-ns"}
+	objectMeta := metav1.ObjectMeta{Name: "test-resource", Namespace: "test-ns"}
 
 	tests := []struct {
 		Name        string
@@ -347,15 +343,8 @@ func TestCleanup(t *testing.T) {
 
 	for _, test := range tests {
 		t.Run(test.Name, func(t *testing.T) {
-			c := client.NewOrDie(&restclient.Config{ContentConfig: restclient.ContentConfig{GroupVersion: &unversioned.GroupVersion{Version: version}}})
-			fakeClient := fake.RESTClient{
-				Codec:  codec,
-				Client: fake.CreateHTTPClient(test.ClientFunc),
-			}
-			c.Client = fakeClient.Client
-
 			ex := executor{
-				kubeClient:  c,
+				kubeClient:  testKubernetesClient(version, fake.CreateHTTPClient(test.ClientFunc)),
 				pod:         test.Pod,
 				credentials: test.Credentials,
 			}
@@ -892,8 +881,7 @@ func TestPrepareIssue2583(t *testing.T) {
 }
 
 func TestSetupCredentials(t *testing.T) {
-	version := testapi.Default.GroupVersion().Version
-	codec := testapi.Default.Codec()
+	version, _ := testVersionAndCodec()
 
 	type testDef struct {
 		Credentials []common.Credentials
@@ -967,15 +955,8 @@ func TestSetupCredentials(t *testing.T) {
 	}
 
 	for _, test := range tests {
-		c := client.NewOrDie(&restclient.Config{ContentConfig: restclient.ContentConfig{GroupVersion: &unversioned.GroupVersion{Version: version}}})
-		fakeClient := fake.RESTClient{
-			Codec:  codec,
-			Client: fake.CreateHTTPClient(fakeClientRoundTripper(test)),
-		}
-		c.Client = fakeClient.Client
-
 		ex := executor{
-			kubeClient: c,
+			kubeClient: testKubernetesClient(version, fake.CreateHTTPClient(fakeClientRoundTripper(test))),
 			options:    &kubernetesOptions{},
 			AbstractExecutor: executors.AbstractExecutor{
 				Config: common.RunnerConfig{
@@ -1010,8 +991,7 @@ func TestSetupCredentials(t *testing.T) {
 }
 
 func TestSetupBuildPod(t *testing.T) {
-	version := testapi.Default.GroupVersion().Version
-	codec := testapi.Default.Codec()
+	version, _ := testVersionAndCodec()
 
 	type testDef struct {
 		RunnerConfig common.RunnerConfig
@@ -1047,7 +1027,7 @@ func TestSetupBuildPod(t *testing.T) {
 			},
 			PrepareFn: func(t *testing.T, test testDef, e *executor) {
 				e.credentials = &api.Secret{
-					ObjectMeta: api.ObjectMeta{
+					ObjectMeta: metav1.ObjectMeta{
 						Name: "job-credentials",
 					},
 				}
@@ -1232,13 +1212,6 @@ func TestSetupBuildPod(t *testing.T) {
 	}
 
 	for _, test := range tests {
-		c := client.NewOrDie(&restclient.Config{ContentConfig: restclient.ContentConfig{GroupVersion: &unversioned.GroupVersion{Version: version}}})
-		fakeClient := fake.RESTClient{
-			Codec:  codec,
-			Client: fake.CreateHTTPClient(fakeClientRoundTripper(test)),
-		}
-		c.Client = fakeClient.Client
-
 		vars := test.Variables
 		if vars == nil {
 			vars = []common.JobVariable{}
@@ -1249,7 +1222,7 @@ func TestSetupBuildPod(t *testing.T) {
 			options = &kubernetesOptions{}
 		}
 		ex := executor{
-			kubeClient: c,
+			kubeClient: testKubernetesClient(version, fake.CreateHTTPClient(fakeClientRoundTripper(test))),
 			options:    options,
 			AbstractExecutor: executors.AbstractExecutor{
 				Config:     test.RunnerConfig,
@@ -1283,13 +1256,15 @@ func TestKubernetesSuccessRun(t *testing.T) {
 
 	successfulBuild, err := common.GetRemoteSuccessfulBuild()
 	assert.NoError(t, err)
-	successfulBuild.Image.Name = "docker:git"
+	successfulBuild.Image.Name = common.TestDockerGitImage
 	build := &common.Build{
 		JobResponse: successfulBuild,
 		Runner: &common.RunnerConfig{
 			RunnerSettings: common.RunnerSettings{
-				Executor:   "kubernetes",
-				Kubernetes: &common.KubernetesConfig{},
+				Executor: "kubernetes",
+				Kubernetes: &common.KubernetesConfig{
+					PullPolicy: common.PullPolicyIfNotPresent,
+				},
 			},
 		},
 	}
@@ -1306,13 +1281,15 @@ func TestKubernetesNoRootImage(t *testing.T) {
 	successfulBuild, err := common.GetRemoteSuccessfulBuildWithDumpedVariables()
 
 	assert.NoError(t, err)
-	successfulBuild.Image.Name = "registry.gitlab.com/gitlab-org/gitlab-runner/alpine-no-root"
+	successfulBuild.Image.Name = common.TestAlpineNoRootImage
 	build := &common.Build{
 		JobResponse: successfulBuild,
 		Runner: &common.RunnerConfig{
 			RunnerSettings: common.RunnerSettings{
-				Executor:   "kubernetes",
-				Kubernetes: &common.KubernetesConfig{},
+				Executor: "kubernetes",
+				Kubernetes: &common.KubernetesConfig{
+					PullPolicy: common.PullPolicyIfNotPresent,
+				},
 			},
 		},
 	}
@@ -1332,17 +1309,19 @@ func TestKubernetesBuildFail(t *testing.T) {
 		JobResponse: failedBuild,
 		Runner: &common.RunnerConfig{
 			RunnerSettings: common.RunnerSettings{
-				Executor:   "kubernetes",
-				Kubernetes: &common.KubernetesConfig{},
+				Executor: "kubernetes",
+				Kubernetes: &common.KubernetesConfig{
+					PullPolicy: common.PullPolicyIfNotPresent,
+				},
 			},
 		},
 	}
-	build.Image.Name = "docker:git"
+	build.Image.Name = common.TestDockerGitImage
 
 	err = build.Run(&common.Config{}, &common.Trace{Writer: os.Stdout})
 	require.Error(t, err, "error")
 	assert.IsType(t, err, &common.BuildError{})
-	assert.Contains(t, err.Error(), "Error executing in Docker Container: 1")
+	assert.Contains(t, err.Error(), "command terminated with exit code")
 }
 
 func TestKubernetesMissingImage(t *testing.T) {
@@ -1404,13 +1383,15 @@ func TestKubernetesBuildAbort(t *testing.T) {
 		JobResponse: failedBuild,
 		Runner: &common.RunnerConfig{
 			RunnerSettings: common.RunnerSettings{
-				Executor:   "kubernetes",
-				Kubernetes: &common.KubernetesConfig{},
+				Executor: "kubernetes",
+				Kubernetes: &common.KubernetesConfig{
+					PullPolicy: common.PullPolicyIfNotPresent,
+				},
 			},
 		},
 		SystemInterrupt: make(chan os.Signal, 1),
 	}
-	build.Image.Name = "docker:git"
+	build.Image.Name = common.TestDockerGitImage
 
 	abortTimer := time.AfterFunc(time.Second, func() {
 		t.Log("Interrupt")
@@ -1439,13 +1420,15 @@ func TestKubernetesBuildCancel(t *testing.T) {
 		JobResponse: failedBuild,
 		Runner: &common.RunnerConfig{
 			RunnerSettings: common.RunnerSettings{
-				Executor:   "kubernetes",
-				Kubernetes: &common.KubernetesConfig{},
+				Executor: "kubernetes",
+				Kubernetes: &common.KubernetesConfig{
+					PullPolicy: common.PullPolicyIfNotPresent,
+				},
 			},
 		},
 		SystemInterrupt: make(chan os.Signal, 1),
 	}
-	build.Image.Name = "docker:git"
+	build.Image.Name = common.TestDockerGitImage
 
 	trace := &common.Trace{Writer: os.Stdout}
 
@@ -1488,12 +1471,13 @@ func TestOverwriteNamespaceNotMatch(t *testing.T) {
 				Executor: "kubernetes",
 				Kubernetes: &common.KubernetesConfig{
 					NamespaceOverwriteAllowed: "^not_a_match$",
+					PullPolicy:                common.PullPolicyIfNotPresent,
 				},
 			},
 		},
 		SystemInterrupt: make(chan os.Signal, 1),
 	}
-	build.Image.Name = "docker:git"
+	build.Image.Name = common.TestDockerGitImage
 
 	err := build.Run(&common.Config{}, &common.Trace{Writer: os.Stdout})
 	require.Error(t, err)
@@ -1522,12 +1506,13 @@ func TestOverwriteServiceAccountNotMatch(t *testing.T) {
 				Executor: "kubernetes",
 				Kubernetes: &common.KubernetesConfig{
 					ServiceAccountOverwriteAllowed: "^not_a_match$",
+					PullPolicy:                     common.PullPolicyIfNotPresent,
 				},
 			},
 		},
 		SystemInterrupt: make(chan os.Signal, 1),
 	}
-	build.Image.Name = "docker:git"
+	build.Image.Name = common.TestDockerGitImage
 
 	err := build.Run(&common.Config{}, &common.Trace{Writer: os.Stdout})
 	require.Error(t, err)
